**************
a2svm
**************


Changelog
#############

0.1.4 (20211027)
*******************

* fix certificate generation
* prevent certbot to used suffixed folder name

0.1.3 (20211027)
*******************

* allow custom certbot options

0.1.2 (20200615)
*******************

* add command to list fqdn
* fix exit code

0.1.1 (20190516)
*******************

* improve Python 3 support

0.1.0 (20190304)
*******************

* Python 3 support
* Black formatting (https://github.com/ambv/black)

0.0.8 (20170608)
*******************

* bugfix on letsencrypt certificate generation with more than one alias

0.0.7 (20170606)
*******************

* include serveralias into letsencrypt certificate

0.0.6 (20170307)
*******************

* add command to launch certificate generation using certbot

0.0.5 (20161106)
*******************

* add compatibility with Debian 8 default apache conf structure

0.0.4 (20130218)
*******************

* make command is now doing more security check (macro existence, arguments number, servername duplication...)


0.0.3 (20130123)
*******************

* List command is now sorting virtualhosts by name
* make command is now support optional argument used for extended macro

0.0.2 (20130116)
*******************

* modify macro base arguments

0.0.1 (20130115)
*******************

* Initial release
